@@ -615,7 +615,7 @@ exports.certificateRequestHandler = async function (event, context) {
       "FAILED",
       physicalResourceId,
       null,
-      `${err.message} (Log: ${defaultLogGroup || context.logGroupName}${
+      `${err.message} (Log: ${defaultLogGroup || context.logGroupName}/${
         defaultLogStream || context.logStreamName
       })`
     );
