@@ -165,6 +165,9 @@ Mutually exclusive with the --%s flag.`, inputFilePathFlag)
 Mutually exclusive with the --%s flag.`, inputFilePathFlag)
 	secretInputFilePathFlagDescription = fmt.Sprintf(`Optional. A YAML file in which the secret values are specified.
 Mutually exclusive with the -%s ,--%s and --%s flags.`, nameFlagShort, nameFlag, valuesFlag)
+
+	repoURLFlagDescription = fmt.Sprintf(`The repository URL to trigger your pipeline.
+Supported providers are: %s`, strings.Join(manifest.PipelineProviders, ", "))
 )
 
 const (
@@ -201,7 +204,6 @@ Defaults to all logs. Only one of end-time / follow may be used.`
 
 	deployTestFlagDescription        = `Deploy your service or job to a "test" environment.`
 	githubURLFlagDescription         = "(Deprecated.) Use --url instead. Repository URL to trigger your pipeline."
-	repoURLFlagDescription           = "The repository URL to trigger your pipeline."
 	githubAccessTokenFlagDescription = "GitHub personal access token for your repository."
 	gitBranchFlagDescription         = "Branch used to trigger your pipeline."
 	pipelineEnvsFlagDescription      = "Environments to add to the pipeline."
