@@ -6,6 +6,7 @@ package cli
 import (
 	"errors"
 	"fmt"
+	"runtime"
 	"strconv"
 
 	"github.com/aws/copilot-cli/internal/pkg/aws/sessions"
@@ -85,14 +86,16 @@ type initSvcOpts struct {
 	initSvcVars
 
 	// Interfaces to interact with dependencies.
-	fs                    afero.Fs
-	init                  svcInitializer
-	prompt                prompter
-	dockerEngineValidator dockerEngineValidator
-	sel                   dockerfileSelector
+	fs           afero.Fs
+	init         svcInitializer
+	prompt       prompter
+	dockerEngine dockerEngine
+	sel          dockerfileSelector
 
 	// Outputs stored on successful actions.
 	manifestPath string
+	os           string
+	arch         string
 
 	// Cache variables
 	df dockerfileParser
@@ -130,11 +133,11 @@ func newInitSvcOpts(vars initSvcVars) (*initSvcOpts, error) {
 	opts := &initSvcOpts{
 		initSvcVars: vars,
 
-		fs:                    fs,
-		init:                  initSvc,
-		prompt:                prompter,
-		sel:                   sel,
-		dockerEngineValidator: exec.NewDockerCommand(),
+		fs:           fs,
+		init:         initSvc,
+		prompt:       prompter,
+		sel:          sel,
+		dockerEngine: exec.NewDockerCommand(),
 	}
 	opts.dockerfile = func(path string) dockerfileParser {
 		if opts.df != nil {
@@ -220,6 +223,11 @@ func (o *initSvcOpts) Execute() error {
 		}
 	}
 
+	o.os, o.arch, err = dockerPlatform(o.dockerEngine, o.image)
+	if err != nil {
+		return err
+	}
+
 	manifestPath, err := o.init.Service(&initialize.ServiceProps{
 		WorkloadProps: initialize.WorkloadProps{
 			App:            o.appName,
@@ -227,6 +235,10 @@ func (o *initSvcOpts) Execute() error {
 			Type:           o.wkldType,
 			DockerfilePath: o.dockerfilePath,
 			Image:          o.image,
+			Platform: &manifest.PlatformConfig{
+				OS:   o.os,
+				Arch: o.arch,
+			},
 		},
 		Port:        o.port,
 		HealthCheck: hc,
@@ -317,7 +329,7 @@ func (o *initSvcOpts) askDockerfile() (isDfSelected bool, err error) {
 	if o.dockerfilePath != "" || o.image != "" {
 		return true, nil
 	}
-	if err = o.dockerEngineValidator.CheckDockerEngineRunning(); err != nil {
+	if err = o.dockerEngine.CheckDockerEngineRunning(); err != nil {
 		var errDaemon *exec.ErrDockerDaemonNotResponsive
 		switch {
 		case errors.Is(err, exec.ErrDockerCommandNotFound):
@@ -420,6 +432,21 @@ func parseHealthCheck(df dockerfileParser) (*manifest.ContainerHealthCheck, erro
 	}, nil
 }
 
+func dockerPlatform(engine dockerEngine, image string) (os, arch string, err error) {
+	os, arch = runtime.GOOS, runtime.GOARCH
+	if image == "" {
+		os, arch, err = engine.GetPlatform()
+		if err != nil {
+			return "", "", fmt.Errorf("get os/arch from docker: %w", err)
+		}
+	}
+	// Until we target X86_64 for ARM architectures, log a warning.
+	if arch == exec.ArmArch || arch == exec.Arm64Arch {
+		log.Warningf("Architecture type %s is currently unsupported.\nTo deploy, run %s\n", arch, "`DOCKER_DEFAULT_PLATFORM=linux/amd64 copilot deploy`")
+	}
+	return os, arch, nil
+}
+
 func svcTypePromptOpts() []prompt.Option {
 	var options []prompt.Option
 	for _, svcType := range manifest.ServiceTypes {
