@@ -6,6 +6,7 @@ package cli
 import (
 	"errors"
 	"fmt"
+	"runtime"
 	"testing"
 
 	"github.com/aws/copilot-cli/internal/pkg/term/prompt"
@@ -123,10 +124,10 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 		inImage          string
 		inSvcPort        uint16
 
-		mockPrompt     func(m *mocks.Mockprompter)
-		mockSel        func(m *mocks.MockdockerfileSelector)
-		mockDockerfile func(m *mocks.MockdockerfileParser)
-		mockValidator  func(m *mocks.MockdockerEngineValidator)
+		mockPrompt       func(m *mocks.Mockprompter)
+		mockSel          func(m *mocks.MockdockerfileSelector)
+		mockDockerfile   func(m *mocks.MockdockerfileParser)
+		mockDockerEngine func(m *mocks.MockdockerEngine)
 
 		wantedErr error
 	}{
@@ -153,10 +154,10 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 				}), gomock.Any()).
 					Return(wantedSvcType, nil)
 			},
-			mockDockerfile: func(m *mocks.MockdockerfileParser) {},
-			mockSel:        func(m *mocks.MockdockerfileSelector) {},
-			mockValidator:  func(m *mocks.MockdockerEngineValidator) {},
-			wantedErr:      nil,
+			mockDockerfile:   func(m *mocks.MockdockerfileParser) {},
+			mockSel:          func(m *mocks.MockdockerfileSelector) {},
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {},
+			wantedErr:        nil,
 		},
 		"return an error if fail to get service type": {
 			inSvcType:        "",
@@ -168,10 +169,10 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 				m.EXPECT().SelectOption(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).
 					Return("", errors.New("some error"))
 			},
-			mockDockerfile: func(m *mocks.MockdockerfileParser) {},
-			mockSel:        func(m *mocks.MockdockerfileSelector) {},
-			mockValidator:  func(m *mocks.MockdockerEngineValidator) {},
-			wantedErr:      fmt.Errorf("select service type: some error"),
+			mockDockerfile:   func(m *mocks.MockdockerfileParser) {},
+			mockSel:          func(m *mocks.MockdockerfileSelector) {},
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {},
+			wantedErr:        fmt.Errorf("select service type: some error"),
 		},
 		"prompt for service name": {
 			inSvcType:        wantedSvcType,
@@ -185,9 +186,9 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 			},
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {
 			},
-			mockSel:       func(m *mocks.MockdockerfileSelector) {},
-			mockValidator: func(m *mocks.MockdockerEngineValidator) {},
-			wantedErr:     nil,
+			mockSel:          func(m *mocks.MockdockerfileSelector) {},
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {},
+			wantedErr:        nil,
 		},
 		"returns an error if fail to get service name": {
 			inSvcType:        wantedSvcType,
@@ -199,10 +200,10 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 				m.EXPECT().Get(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).
 					Return("", errors.New("some error"))
 			},
-			mockDockerfile: func(m *mocks.MockdockerfileParser) {},
-			mockSel:        func(m *mocks.MockdockerfileSelector) {},
-			mockValidator:  func(m *mocks.MockdockerEngineValidator) {},
-			wantedErr:      fmt.Errorf("get service name: some error"),
+			mockDockerfile:   func(m *mocks.MockdockerfileParser) {},
+			mockSel:          func(m *mocks.MockdockerfileSelector) {},
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {},
+			wantedErr:        fmt.Errorf("get service name: some error"),
 		},
 		"skip selecting Dockerfile if image flag is set": {
 			inSvcType:        wantedSvcType,
@@ -211,11 +212,11 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 			inImage:          "mockImage",
 			inDockerfilePath: "",
 
-			mockPrompt:     func(m *mocks.Mockprompter) {},
-			mockSel:        func(m *mocks.MockdockerfileSelector) {},
-			mockDockerfile: func(m *mocks.MockdockerfileParser) {},
-			mockValidator:  func(m *mocks.MockdockerEngineValidator) {},
-			wantedErr:      nil,
+			mockPrompt:       func(m *mocks.Mockprompter) {},
+			mockSel:          func(m *mocks.MockdockerfileSelector) {},
+			mockDockerfile:   func(m *mocks.MockdockerfileParser) {},
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {},
+			wantedErr:        nil,
 		},
 		"return error if failed to check if docker engine is running": {
 			inSvcType: wantedSvcType,
@@ -225,7 +226,7 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 			mockPrompt:     func(m *mocks.Mockprompter) {},
 			mockSel:        func(m *mocks.MockdockerfileSelector) {},
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {},
-			mockValidator: func(m *mocks.MockdockerEngineValidator) {
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {
 				m.EXPECT().CheckDockerEngineRunning().Return(errors.New("some error"))
 			},
 			wantedErr: fmt.Errorf("check if docker engine is running: some error"),
@@ -241,7 +242,7 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 			},
 			mockSel:        func(m *mocks.MockdockerfileSelector) {},
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {},
-			mockValidator: func(m *mocks.MockdockerEngineValidator) {
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {
 				m.EXPECT().CheckDockerEngineRunning().Return(exec.ErrDockerCommandNotFound)
 			},
 			wantedErr: nil,
@@ -257,7 +258,7 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 			},
 			mockSel:        func(m *mocks.MockdockerfileSelector) {},
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {},
-			mockValidator: func(m *mocks.MockdockerEngineValidator) {
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {
 				m.EXPECT().CheckDockerEngineRunning().Return(&exec.ErrDockerDaemonNotResponsive{})
 			},
 			wantedErr: nil,
@@ -282,7 +283,7 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 				).Return("Use an existing image instead", nil)
 			},
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {},
-			mockValidator: func(m *mocks.MockdockerEngineValidator) {
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {
 				m.EXPECT().CheckDockerEngineRunning().Return(nil)
 			},
 			wantedErr: fmt.Errorf("get image location: mock error"),
@@ -308,7 +309,7 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 				).Return("Use an existing image instead", nil)
 			},
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {},
-			mockValidator: func(m *mocks.MockdockerEngineValidator) {
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {
 				m.EXPECT().CheckDockerEngineRunning().Return(nil)
 			},
 		},
@@ -329,7 +330,7 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 				).Return("frontend/Dockerfile", nil)
 			},
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {},
-			mockValidator: func(m *mocks.MockdockerEngineValidator) {
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {
 				m.EXPECT().CheckDockerEngineRunning().Return(nil)
 			},
 			wantedErr: nil,
@@ -347,7 +348,7 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 			},
 			mockPrompt:     func(m *mocks.Mockprompter) {},
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {},
-			mockValidator: func(m *mocks.MockdockerEngineValidator) {
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {
 				m.EXPECT().CheckDockerEngineRunning().Return(nil)
 			},
 			wantedErr: fmt.Errorf("select Dockerfile: some error"),
@@ -361,9 +362,9 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {
 				m.EXPECT().GetExposedPorts().Return([]uint16{}, errors.New("no expose"))
 			},
-			mockSel:       func(m *mocks.MockdockerfileSelector) {},
-			mockValidator: func(m *mocks.MockdockerEngineValidator) {},
-			wantedErr:     nil,
+			mockSel:          func(m *mocks.MockdockerfileSelector) {},
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {},
+			wantedErr:        nil,
 		},
 		"asks for port if not specified": {
 			inSvcType:        wantedSvcType,
@@ -378,9 +379,9 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {
 				m.EXPECT().GetExposedPorts().Return([]uint16{}, errors.New("no expose"))
 			},
-			mockSel:       func(m *mocks.MockdockerfileSelector) {},
-			mockValidator: func(m *mocks.MockdockerEngineValidator) {},
-			wantedErr:     nil,
+			mockSel:          func(m *mocks.MockdockerfileSelector) {},
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {},
+			wantedErr:        nil,
 		},
 		"errors if port not specified": {
 			inSvcType:        wantedSvcType,
@@ -395,9 +396,9 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {
 				m.EXPECT().GetExposedPorts().Return([]uint16{}, errors.New("expose error"))
 			},
-			mockSel:       func(m *mocks.MockdockerfileSelector) {},
-			mockValidator: func(m *mocks.MockdockerEngineValidator) {},
-			wantedErr:     fmt.Errorf("get port: some error"),
+			mockSel:          func(m *mocks.MockdockerfileSelector) {},
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {},
+			wantedErr:        fmt.Errorf("get port: some error"),
 		},
 		"errors if port out of range": {
 			inSvcType:        wantedSvcType,
@@ -412,9 +413,9 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {
 				m.EXPECT().GetExposedPorts().Return([]uint16{}, errors.New("no expose"))
 			},
-			mockSel:       func(m *mocks.MockdockerfileSelector) {},
-			mockValidator: func(m *mocks.MockdockerEngineValidator) {},
-			wantedErr:     fmt.Errorf("get port: some error"),
+			mockSel:          func(m *mocks.MockdockerfileSelector) {},
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {},
+			wantedErr:        fmt.Errorf("get port: some error"),
 		},
 		"don't ask if dockerfile has port": {
 			inSvcType:        wantedSvcType,
@@ -427,8 +428,8 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {
 				m.EXPECT().GetExposedPorts().Return([]uint16{80}, nil)
 			},
-			mockSel:       func(m *mocks.MockdockerfileSelector) {},
-			mockValidator: func(m *mocks.MockdockerEngineValidator) {},
+			mockSel:          func(m *mocks.MockdockerfileSelector) {},
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {},
 		},
 		"don't use dockerfile port if flag specified": {
 			inSvcType:        wantedSvcType,
@@ -438,9 +439,9 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 
 			mockPrompt: func(m *mocks.Mockprompter) {
 			},
-			mockDockerfile: func(m *mocks.MockdockerfileParser) {},
-			mockSel:        func(m *mocks.MockdockerfileSelector) {},
-			mockValidator:  func(m *mocks.MockdockerEngineValidator) {},
+			mockDockerfile:   func(m *mocks.MockdockerfileParser) {},
+			mockSel:          func(m *mocks.MockdockerfileSelector) {},
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {},
 		},
 	}
 
@@ -453,7 +454,7 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 			mockPrompt := mocks.NewMockprompter(ctrl)
 			mockDockerfile := mocks.NewMockdockerfileParser(ctrl)
 			mockSel := mocks.NewMockdockerfileSelector(ctrl)
-			mockValidator := mocks.NewMockdockerEngineValidator(ctrl)
+			mockDockerEngine := mocks.NewMockdockerEngine(ctrl)
 			opts := &initSvcOpts{
 				initSvcVars: initSvcVars{
 					initWkldVars: initWkldVars{
@@ -468,15 +469,15 @@ func TestSvcInitOpts_Ask(t *testing.T) {
 				dockerfile: func(s string) dockerfileParser {
 					return mockDockerfile
 				},
-				df:                    mockDockerfile,
-				prompt:                mockPrompt,
-				sel:                   mockSel,
-				dockerEngineValidator: mockValidator,
+				df:           mockDockerfile,
+				prompt:       mockPrompt,
+				sel:          mockSel,
+				dockerEngine: mockDockerEngine,
 			}
 			tc.mockSel(mockSel)
 			tc.mockPrompt(mockPrompt)
 			tc.mockDockerfile(mockDockerfile)
-			tc.mockValidator(mockValidator)
+			tc.mockDockerEngine(mockDockerEngine)
 
 			// WHEN
 			err := opts.Ask()
@@ -502,6 +503,7 @@ func TestSvcInitOpts_Execute(t *testing.T) {
 	testCases := map[string]struct {
 		mockSvcInit      func(m *mocks.MocksvcInitializer)
 		mockDockerfile   func(m *mocks.MockdockerfileParser)
+		mockDockerEngine func(m *mocks.MockdockerEngine)
 		inSvcPort        uint16
 		inSvcType        string
 		inSvcName        string
@@ -527,6 +529,10 @@ func TestSvcInitOpts_Execute(t *testing.T) {
 						Name:           "frontend",
 						Type:           "Load Balanced Web Service",
 						DockerfilePath: "./Dockerfile",
+						Platform: &manifest.PlatformConfig{
+							OS:   "linux",
+							Arch: "amd64",
+						},
 					},
 					Port: 80,
 				}).Return("manifest/path", nil)
@@ -534,6 +540,9 @@ func TestSvcInitOpts_Execute(t *testing.T) {
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {
 				m.EXPECT().GetHealthCheck().Return(nil, nil)
 			},
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {
+				m.EXPECT().GetPlatform().Return("linux", "amd64", nil)
+			},
 
 			wantedManifestPath: "manifest/path",
 		},
@@ -550,12 +559,19 @@ func TestSvcInitOpts_Execute(t *testing.T) {
 						Name:           "frontend",
 						Type:           "Backend Service",
 						DockerfilePath: "./Dockerfile",
+						Platform: &manifest.PlatformConfig{
+							OS:   "linux",
+							Arch: "amd64",
+						},
 					},
 				}).Return("manifest/path", nil)
 			},
 			mockDockerfile: func(m *mocks.MockdockerfileParser) {
 				m.EXPECT().GetHealthCheck().Return(nil, nil)
 			},
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {
+				m.EXPECT().GetPlatform().Return("linux", "amd64", nil)
+			},
 
 			wantedManifestPath: "manifest/path",
 		},
@@ -573,6 +589,10 @@ func TestSvcInitOpts_Execute(t *testing.T) {
 						Name:  "backend",
 						Type:  "Backend Service",
 						Image: "nginx:latest",
+						Platform: &manifest.PlatformConfig{
+							OS:   runtime.GOOS,
+							Arch: runtime.GOARCH,
+						},
 					},
 				}).Return("manifest/path", nil)
 			},
@@ -594,6 +614,10 @@ func TestSvcInitOpts_Execute(t *testing.T) {
 						Name:  "frontend",
 						Type:  "Load Balanced Web Service",
 						Image: "nginx:latest",
+						Platform: &manifest.PlatformConfig{
+							OS:   runtime.GOOS,
+							Arch: runtime.GOARCH,
+						},
 					},
 				}).Return("manifest/path", nil)
 			},
@@ -601,7 +625,16 @@ func TestSvcInitOpts_Execute(t *testing.T) {
 
 			wantedManifestPath: "manifest/path",
 		},
+		"return error if OS/arch detection fails": {
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {
+				m.EXPECT().GetPlatform().Return("", "", mockError)
+			},
+			wantedErr: errors.New("get os/arch from docker: mock error"),
+		},
 		"failure": {
+			mockDockerEngine: func(m *mocks.MockdockerEngine) {
+				m.EXPECT().GetPlatform().Return("linux", "amd64", nil)
+			},
 			mockSvcInit: func(m *mocks.MocksvcInitializer) {
 				m.EXPECT().Service(gomock.Any()).Return("", errors.New("some error"))
 			},
@@ -617,6 +650,7 @@ func TestSvcInitOpts_Execute(t *testing.T) {
 
 			mockSvcInitializer := mocks.NewMocksvcInitializer(ctrl)
 			mockDockerfile := mocks.NewMockdockerfileParser(ctrl)
+			mockDockerEngine := mocks.NewMockdockerEngine(ctrl)
 
 			if tc.mockSvcInit != nil {
 				tc.mockSvcInit(mockSvcInitializer)
@@ -624,7 +658,9 @@ func TestSvcInitOpts_Execute(t *testing.T) {
 			if tc.mockDockerfile != nil {
 				tc.mockDockerfile(mockDockerfile)
 			}
-
+			if tc.mockDockerEngine != nil {
+				tc.mockDockerEngine(mockDockerEngine)
+			}
 			opts := initSvcOpts{
 				initSvcVars: initSvcVars{
 					initWkldVars: initWkldVars{
@@ -640,7 +676,8 @@ func TestSvcInitOpts_Execute(t *testing.T) {
 				dockerfile: func(s string) dockerfileParser {
 					return mockDockerfile
 				},
-				df: mockDockerfile,
+				df:           mockDockerfile,
+				dockerEngine: mockDockerEngine,
 			}
 
 			// WHEN
