@@ -48,8 +48,8 @@ type AppRegionalResources struct {
 }
 
 const (
-	fmtAppTemplatePath            = "app/versions/%s/app.yml"
-	fmtAppResourcesTemplatePath   = "app/versions/%s/cf.yml"
+	appTemplatePath               = "app/app.yml"
+	appResourcesTemplatePath      = "app/cf.yml"
 	appAdminRoleParamName         = "AdminRoleName"
 	appExecutionRoleParamName     = "ExecutionRoleName"
 	appDNSDelegationRoleParamName = "DNSDelegationRoleName"
@@ -89,10 +89,13 @@ func NewAppStackConfig(in *deploy.CreateAppInput) *AppStackConfig {
 
 // Template returns the environment CloudFormation template.
 func (c *AppStackConfig) Template() (string, error) {
-	// content, err := c.parser.Read(appTemplatePath(c.Version))
-	content, err := c.parser.Parse(appTemplatePath(c.Version), struct {
-		TemplateVersion string
-	}{c.Version})
+	content, err := c.parser.Parse(appTemplatePath, struct {
+		TemplateVersion         string
+		AppDNSDelegatedAccounts []string
+	}{
+		c.Version,
+		c.dnsDelegationAccounts(),
+	})
 	if err != nil {
 		return "", err
 	}
@@ -105,7 +108,7 @@ func (c *AppStackConfig) ResourceTemplate(config *AppResourcesConfig) (string, e
 	sort.Strings(config.Accounts)
 	sort.Strings(config.Services)
 
-	content, err := c.parser.Parse(appResourcesTemplatePath(c.Version), struct {
+	content, err := c.parser.Parse(appResourcesTemplatePath, struct {
 		*AppResourcesConfig
 		ServiceTagKey   string
 		TemplateVersion string
@@ -120,20 +123,6 @@ func (c *AppStackConfig) ResourceTemplate(config *AppResourcesConfig) (string, e
 	return content.String(), err
 }
 
-func appTemplatePath(version string) string {
-	if version == "" {
-		return fmt.Sprintf(fmtAppTemplatePath, "v0.0.0")
-	}
-	return fmt.Sprintf(fmtAppTemplatePath, version)
-}
-
-func appResourcesTemplatePath(version string) string {
-	if version == "" {
-		return fmt.Sprintf(fmtAppResourcesTemplatePath, "v0.0.0")
-	}
-	return fmt.Sprintf(fmtAppResourcesTemplatePath, version)
-}
-
 // Parameters returns a list of parameters which accompany the app CloudFormation template.
 func (c *AppStackConfig) Parameters() ([]*cloudformation.Parameter, error) {
 	return []*cloudformation.Parameter{
