@@ -151,6 +151,11 @@ func (s *LoadBalancedWebService) Template() (string, error) {
 			aliases = append(aliases, albAlias)
 		}
 	}
+
+	var allowedSourceIPs []string
+	if s.manifest.AllowedSourceIps != nil {
+		allowedSourceIPs = *s.manifest.AllowedSourceIps
+	}
 	content, err := s.parser.ParseLoadBalancedWebService(template.WorkloadOpts{
 		Variables:           s.manifest.Variables,
 		Secrets:             s.manifest.Secrets,
@@ -166,7 +171,7 @@ func (s *LoadBalancedWebService) Template() (string, error) {
 		WorkloadType:        manifest.LoadBalancedWebServiceType,
 		HealthCheck:         s.manifest.ImageConfig.HealthCheckOpts(),
 		HTTPHealthCheck:     convertHTTPHealthCheck(&s.manifest.HealthCheck),
-		AllowedSourceIps:    s.manifest.AllowedSourceIps,
+		AllowedSourceIps:    allowedSourceIPs,
 		RulePriorityLambda:  rulePriorityLambda.String(),
 		DesiredCountLambda:  desiredCountLambda.String(),
 		EnvControllerLambda: envControllerLambda.String(),
@@ -195,10 +200,13 @@ func (s *LoadBalancedWebService) loadBalancerTarget() (targetContainer *string,
 	if mftTargetContainer != nil {
 		sidecar, ok := s.manifest.Sidecars[*mftTargetContainer]
 		if ok {
+			if sidecar.Port == nil {
+				return nil, nil, fmt.Errorf("target container %s doesn't expose any port", *mftTargetContainer)
+			}
 			targetContainer = mftTargetContainer
 			targetPort = sidecar.Port
 		} else {
-			return nil, nil, fmt.Errorf("target container %s doesn't exist", *s.manifest.TargetContainer)
+			return nil, nil, fmt.Errorf("target container %s doesn't exist", *mftTargetContainer)
 		}
 	}
 	return
