@@ -359,15 +359,14 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 			Enable: aws.Bool(true),
 		},
 	}
-	testLBWebServiceManifestWithBadSidecar := manifest.NewLoadBalancedWebService(&manifest.LoadBalancedWebServiceProps{
-		WorkloadProps: &manifest.WorkloadProps{
-			Name:       "frontend",
-			Dockerfile: "frontend/Dockerfile",
-		},
-		Path: "frontend",
-		Port: 80,
-	})
-	testLBWebServiceManifestWithBadSidecar.TargetContainer = aws.String("xray")
+	testLBWebServiceManifestWithBadSidecarName := manifest.NewLoadBalancedWebService(baseProps)
+	testLBWebServiceManifestWithBadSidecarName.TargetContainer = aws.String("xray")
+
+	testLBWebServiceManifestWithBadSidecarPort := manifest.NewLoadBalancedWebService(baseProps)
+	testLBWebServiceManifestWithBadSidecarPort.TargetContainer = aws.String("xray")
+	testLBWebServiceManifestWithBadSidecarPort.Sidecars = map[string]*manifest.SidecarConfig{
+		"xray": {},
+	}
 	expectedParams := []*cloudformation.Parameter{
 		{
 			ParameterKey:   aws.String(WorkloadAppNameParamKey),
@@ -554,10 +553,16 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 		},
 		"with bad sidecar container": {
 			httpsEnabled: true,
-			manifest:     testLBWebServiceManifestWithBadSidecar,
+			manifest:     testLBWebServiceManifestWithBadSidecarName,
 
 			expectedErr: fmt.Errorf("target container xray doesn't exist"),
 		},
+		"with target sidecar container with empty port": {
+			httpsEnabled: true,
+			manifest:     testLBWebServiceManifestWithBadSidecarPort,
+
+			expectedErr: fmt.Errorf("target container xray doesn't expose any port"),
+		},
 		"with bad count": {
 			httpsEnabled: true,
 			manifest:     testLBWebServiceManifestWithBadCount,
