@@ -28,11 +28,6 @@ const (
 	defaultWritePermission = false
 )
 
-// Default value for Sidecar port.
-const (
-	defaultSidecarPort = "80"
-)
-
 // Min and Max values for task ephemeral storage in GiB.
 const (
 	ephemeralMinValueGiB = 21
@@ -130,8 +125,7 @@ func convertImageDependsOn(s convertSidecarOpts) (map[string]string, error) {
 // Valid sidecar portMapping example: 2000/udp, or 2000 (default to be tcp).
 func parsePortMapping(s *string) (port *string, protocol *string, err error) {
 	if s == nil {
-		// default port for sidecar container to be 80.
-		return aws.String(defaultSidecarPort), nil, nil
+		return nil, nil, nil
 	}
 	portProtocol := strings.Split(*s, "/")
 	switch len(portProtocol) {
