@@ -191,11 +191,11 @@ func (w *wkld) templateConfiguration(tc templateConfigurer) (string, error) {
 func (w *wkld) addonsOutputs() (*template.WorkloadNestedStackOpts, error) {
 	stack, err := w.addons.Template()
 	if err != nil {
-		var noAddonsErr *addon.ErrAddonsDirNotExist
-		if !errors.As(err, &noAddonsErr) {
+		var notFoundErr *addon.ErrAddonsNotFound
+		if !errors.As(err, &notFoundErr){
 			return nil, fmt.Errorf("generate addons template for %s: %w", w.name, err)
 		}
-		return nil, nil // Addons directory does not exist, so there are no outputs and error.
+		return nil, nil // No addons found, so there are no outputs and error.
 	}
 
 	out, err := addon.Outputs(stack)
