@@ -211,8 +211,8 @@ func (i *Image) cacheFrom() []string {
 
 // ImageOverride holds fields that override Dockerfile image defaults.
 type ImageOverride struct {
-	EntryPoint *EntryPointOverride `yaml:"entrypoint"`
-	Command    *CommandOverride    `yaml:"command"`
+	EntryPoint *EntryPointOverride `yaml:"entrypoint"` // TODO: the type needs to be updated after we upgrade mergo
+	Command    *CommandOverride    `yaml:"command"`    // TODO: the type needs to be updated after we upgrade mergo
 }
 
 // EntryPointOverride is a custom type which supports unmarshaling "entrypoint" yaml which
@@ -450,11 +450,28 @@ type TaskConfig struct {
 	Storage        *Storage          `yaml:"storage"`
 }
 
+// PublishConfig represents the configurable options for setting up publishers.
+type PublishConfig struct {
+	Topics []Topic `yaml:"topics"`
+}
+
+// Topic represents the configurable options for setting up a SNS Topic.
+type Topic struct {
+	Name           *string  `yaml:"name"`
+	AllowedWorkers []string `yaml:"allowed_workers"`
+}
+
 // NetworkConfig represents options for network connection to AWS resources within a VPC.
 type NetworkConfig struct {
 	VPC *vpcConfig `yaml:"vpc"`
 }
 
+// PlatformConfig represents operating system and architecture specifications.
+type PlatformConfig struct {
+	OS   string `yaml:"os"`
+	Arch string `yaml:"architecture"`
+}
+
 // UnmarshalYAML ensures that a NetworkConfig always defaults to public subnets.
 // If the user specified a placement that's not valid then throw an error.
 func (c *NetworkConfig) UnmarshalYAML(unmarshal func(interface{}) error) error {
